@@ -592,6 +592,10 @@ objects=(\
                     "obj, center, segment,", "(obj, center, segment),"),
 ("Scale2",          "ScalingOverCenter2",
                     "obj, center, s1, s2,", "(obj, center, s1, s2),"),
+("Stretch",         "ScalingOverLine",
+                    "obj, line, segment,", "(obj, line, segment),"),
+("Stretch2",        "ScalingOverLine2",
+                    "obj, line, s1, s2,", "(obj, line, s1, s2),"),
 ("InvertPoint",     "InvertPoint",
                     "point, circle,", "(point, circle),"),
 ("CircularInversion", "CircularInversion",
